==> alg-common-2.8.0-20191128.112003-7-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/SelectPoolInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 * @author lijingzhe
 * @description 优选bean
 * @date 2019/8/22
 */
public class SelectPoolInfo {
    /**
     * 收益
     */
    private double reward;
    /**
     * 活动类型
     */
    private long activityType;
    /**
     * 索引
     */
    private int index;
    /**
     * 活动id
     */
    private long activityId;
    /**
     * 转化分
     */
    private double changeScore;
    /**
     * 广告位+活动每pv消耗
     */
    private double hrpm;
    /**
     * 媒体+活动每pv消耗
     */
    private double arpm;
    /**
     * 全局每pv消耗
     */
    private double grpm;
    /**
     * 活动访问pv
     */
    private double request;
    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    private int subType;
    /**
     * 是否是优质活动
     */
    private boolean excellent;
    /**
     * 归一化分数
     */
    private double scores;
    /**
     * 广告位cvr
     */
    private double cvrBias;
    /**
     * 广告位每uv券点击
     */
    double uvClick;
    /**
     * 广告位真实cvr
     */
    double cvr;
    /**
     * 广告位每uv消耗
     */
    double uvCost;
    /**
     * 广告位+活动每uv券点击
     */
    double sUvClick;
    /**
     * 广告位+活动真实cvr
     */
    double sCvr;

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public double getHrpm() {
        return hrpm;
    }

    public void setHrpm(double hrpm) {
        this.hrpm = hrpm;
    }

    public double getArpm() {
        return arpm;
    }

    public void setArpm(double arpm) {
        this.arpm = arpm;
    }

    public double getGrpm() {
        return grpm;
    }

    public void setGrpm(double grpm) {
        this.grpm = grpm;
    }

    public double getRequest() {
        return request;
    }

    public void setRequest(double request) {
        this.request = request;
    }

    public boolean isExcellent() {
        return excellent;
    }

    public void setExcellent(boolean excellent) {
        this.excellent = excellent;
    }

    public double getScores() {
        return scores;
    }

    public void setScores(double scores) {
        this.scores = scores;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public double getCvrBias() {
        return cvrBias;
    }

    public void setCvrBias(double cvrBias) {
        this.cvrBias = cvrBias;
    }

    public double getUvCost() {
        return uvCost;
    }

    public void setUvCost(double uvCost) {
        this.uvCost = uvCost;
    }

    public double getUvClick() {
        return uvClick;
    }

    public void setUvClick(double uvClick) {
        this.uvClick = uvClick;
    }

    public double getCvr() {
        return cvr;
    }

    public void setCvr(double cvr) {
        this.cvr = cvr;
    }

    public double getsUvClick() {
        return sUvClick;
    }

    public void setsUvClick(double sUvClick) {
        this.sUvClick = sUvClick;
    }

    public double getsCvr() {
        return sCvr;
    }

    public void setsCvr(double sCvr) {
        this.sCvr = sCvr;
    }
}

==> alg-common-3.1.10-20200110.090602-5-sources.jar: cn/com/duiba/nezha/alg/common/model/activityrecommend/SelectPoolInfo.java <==
package cn.com.duiba.nezha.alg.common.model.activityrecommend;

/**
 * @author lijingzhe
 * @description 优选bean
 * @date 2019/8/22
 */
public class SelectPoolInfo {
    /**
     * 收益
     */
    private double reward;
    /**
     * 活动类型
     */
    private long activityType;
    /**
     * 索引
     */
    private int index;
    /**
     * 活动id
     */
    private long activityId;
    /**
     * 转化分
     */
    private double changeScore;
    /**
     * 广告位+活动每pv消耗
     */
    private double hrpm;
    /**
     * 媒体+活动每pv消耗
     */
    private double arpm;
    /**
     * 全局每pv消耗
     */
    private double grpm;
    /**
     * 活动访问pv
     */
    private double request;
    /**
     * v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
     */
    private int subType;
    /**
     * 是否是优质活动
     */
    private boolean excellent;
    /**
     * 归一化分数
     */
    private double scores;
    /**
     * 广告位cvr
     */
    private double cvrBias;
    /**
     * 广告位每uv券点击
     */
    double uvClick;
    /**
     * 广告位真实cvr
     */
    double cvr;
    /**
     * 广告位每uv消耗
     */
    double uvCost;
    /**
     * 广告位+活动每uv券点击
     */
    double sUvClick;
    /**
     * 广告位+活动真实cvr
     */
    double sCvr;

    public double getReward() {
        return reward;
    }

    public void setReward(double reward) {
        this.reward = reward;
    }

    public long getActivityType() {
        return activityType;
    }

    public void setActivityType(long activityType) {
        this.activityType = activityType;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public double getHrpm() {
        return hrpm;
    }

    public void setHrpm(double hrpm) {
        this.hrpm = hrpm;
    }

    public double getArpm() {
        return arpm;
    }

    public void setArpm(double arpm) {
        this.arpm = arpm;
    }

    public double getGrpm() {
        return grpm;
    }

    public void setGrpm(double grpm) {
        this.grpm = grpm;
    }

    public double getRequest() {
        return request;
    }

    public void setRequest(double request) {
        this.request = request;
    }

    public boolean isExcellent() {
        return excellent;
    }

    public void setExcellent(boolean excellent) {
        this.excellent = excellent;
    }

    public double getScores() {
        return scores;
    }

    public void setScores(double scores) {
        this.scores = scores;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public double getCvrBias() {
        return cvrBias;
    }

    public void setCvrBias(double cvrBias) {
        this.cvrBias = cvrBias;
    }

    public double getUvCost() {
        return uvCost;
    }

    public void setUvCost(double uvCost) {
        this.uvCost = uvCost;
    }

    public double getUvClick() {
        return uvClick;
    }

    public void setUvClick(double uvClick) {
        this.uvClick = uvClick;
    }

    public double getCvr() {
        return cvr;
    }

    public void setCvr(double cvr) {
        this.cvr = cvr;
    }

    public double getsUvClick() {
        return sUvClick;
    }

    public void setsUvClick(double sUvClick) {
        this.sUvClick = sUvClick;
    }

    public double getsCvr() {
        return sCvr;
    }

    public void setsCvr(double sCvr) {
        this.sCvr = sCvr;
    }

    @Override
    public String toString() {
        return "SelectPoolInfo{" +
                "reward=" + reward +
                ", activityId=" + activityId +
                ", hrpm=" + hrpm +
                ", request=" + request +
                ", cvrBias=" + cvrBias +
                ", uvClick=" + uvClick +
                ", cvr=" + cvr +
                ", uvCost=" + uvCost +
                ", sUvClick=" + sUvClick +
                ", sCvr=" + sCvr +
                '}';
    }
}
